Index: src/mips/macro-assembler-mips.h |
diff --git a/src/mips/macro-assembler-mips.h b/src/mips/macro-assembler-mips.h |
index 7a2c209514c90e240ef6a8186c4d7a32e9a57cf3..0bc1e15aa829ab81a578751a0ea2028a08113c7d 100644 |
--- a/src/mips/macro-assembler-mips.h |
+++ b/src/mips/macro-assembler-mips.h |
@@ -1080,14 +1080,12 @@ class MacroAssembler: public Assembler { |
Label* fail, |
SmiCheckType smi_check_type); |
- // Check if the map of an object is equal to a specified map and branch to a |
- // specified target if equal. Skip the smi check if not required (object is |
- // known to be a heap object) |
- void DispatchMap(Register obj, |
- Register scratch, |
- Handle<Map> map, |
- Handle<Code> success, |
- SmiCheckType smi_check_type); |
+ // Check if the map of an object is equal to a specified weak map and branch |
+ // to a specified target if equal. Skip the smi check if not required |
+ // (object is known to be a heap object) |
+ void DispatchWeakMap(Register obj, Register scratch1, Register scratch2, |
+ Handle<WeakCell> cell, Handle<Code> success, |
+ SmiCheckType smi_check_type); |
// Get value of the weak cell. |
void GetWeakValue(Register value, Handle<WeakCell> cell); |